@@ -64,10 +64,15 @@ def _get_c_string(data):
 def _make_c_string(string):
     if "\x00" in string:
         raise InvalidStringData("BSON strings must not contain a NULL character")
-    try:
+    if isinstance(string, unicode):
         return string.encode("utf-8") + "\x00"
-    except:
-        raise InvalidStringData("strings in documents must be ASCII only")
+    else:
+        try:
+            string.decode("utf-8")
+            return string + "\x00"
+        except:
+            raise InvalidStringData("strings in documents must be valid "
+                                    "UTF-8: %r" % string)
 
 
 def _validate_number(data):
@@ -474,6 +479,9 @@ def _dict_to_bson(dict, check_keys):
         raise TypeError("encoder expected a mapping type but got: %r" % dict)
 
     length = len(elements) + 5
+    if length > 4 * 1024 * 1024:
+        raise InvalidDocument("document too large - BSON documents are limited "
+                              "to 4 MB")
     return struct.pack("<i", length) + elements + "\x00"
 if _use_c:
     _dict_to_bson = _cbson._dict_to_bson
@@ -513,6 +521,10 @@ def is_valid(bson):
     if not isinstance(bson, types.StringType):
         raise TypeError("BSON data must be an instance of a subclass of str")
 
+    # 4 MB limit
+    if len(bson) > 4 * 1024 * 1024:
+        raise InvalidBSON("BSON documents are limited to 4MB")
+
     try:
         remainder = _validate_document(bson)
         return remainder == ""
