@@ -43,7 +43,7 @@ class TestDatabase(unittest.TestCase):
     def test_name(self):
         self.assertRaises(TypeError, Database, self.connection, 4)
         self.assertRaises(InvalidName, Database, self.connection, "my db")
-        self.assertEqual("name", Database(self.connection, "name").name())
+        self.assertEqual("name", Database(self.connection, "name").name)
 
     def test_cmp(self):
         self.assertNotEqual(Database(self.connection, "test"),
